@@ -226,10 +226,17 @@ class sqlobj(object):
 
 		return output
 
-	def addr(self, sheet_name, dataframe, if_exists='replace'):
+	def addr(self, sheet_name, og_dataframe, drop_columns={'level_0':'equals','Unnamed':'startswith'},if_exists='replace'):
+		dataframe = dc(og_dataframe)
 		while sheet_name in list(self.keys()):
 			sheet_name += "_"
 
+		for col in list(dataframe.columns):
+			for drop_col, drop_match in drop_columns.items():
+				if col.startswith(drop_col) if dropmatch == 'startswith' else col == drop_col:
+					dataframe.drop(columns=[col],inplace=True)
+					break
+
 		just_enter = False
 		if self.exists is None:
 			just_enter = True
@@ -242,8 +249,8 @@ class sqlobj(object):
 
 		return self
 
-	def add_frame(self, sheet_name, dataframe):
-		self.addr(sheet_name, dataframe)
+	def add_frame(self, sheet_name, dataframe),drop_columns={'level_0':'equals','Unnamed':'startswith'},:
+		self.addr(sheet_name, dataframe, drop_columns=drop_columns)
 
 	def add_csv(self, filename):
 		if os.path.exists(filename):
